Status

Trait Status 

pub trait Status {
    // Required method
    fn succeeded(&self) -> bool;

    // Provided method
    fn error(&self) -> Option<String> { ... }
}
Common interface used by tracing to inspect a jig’s outcome without knowing whether the value is a Request, Response, or Branch.

Required Methods

fn succeeded(&self) -> bool

Returns true if the value represents a successful outcome.

Provided Methods

fn error(&self) -> Option<String>

Error message, if any. Defaults to None.

Implementors

Source

impl<REQ, RESP> Status for Branch<REQ, RESP>
where REQ: Request, RESP: Response,