Step

Trait Step 

pub trait Step {
    type Out;
    type Fut: Future<Output = Self::Out>;

    // Required method
    fn into_step(self) -> Self::Fut;
}
Lifts the output of a jig into a future, so async and sync jigs can be chained uniformly inside a Pending chain. Sync values become a Ready future, a nested Pending is unwrapped to its inner future.

Required Associated Types

type Out

Resolved output of this step.

type Fut: Future<Output = Self::Out>

Future yielding the output.

Required Methods

fn into_step(self) -> Self::Fut

Convert this value into the future the chain awaits.

Implementors

Source

impl<F> Step for Pending<F>
where F: Future,

Source

type Out = <F as Future>::Output

Source

type Fut = F

Source

impl<R, P> Step for Branch<R, P>

Source

type Out = Branch<R, P>

Source

type Fut = Ready<Branch<R, P>>

Source

impl<T> Step for Request<T>

Source

impl<T> Step for Response<T>