Status

Trait Status 

pub trait Status {
    // Required method
    fn ok(&self) -> bool;

    // Provided method
    fn error(&self) -> Option<String> { ... }
}
Common interface used by tracing to inspect a jig’s outcome without knowing whether the value is a Request, Response, or Branch.

Required Methods

fn ok(&self) -> bool

Returns true if the value represents a successful outcome.

Provided Methods

fn error(&self) -> Option<String>

Error message, if any. Defaults to None.

Implementors

Source

impl<Req, Resp> Status for Branch<Req, Resp>

Source

impl<T> Status for Request<T>

Source

impl<T> Status for Response<T>