pub trait Status {
// Required method
fn ok(&self) -> bool;
// Provided method
fn error(&self) -> Option<String> { ... }
}Expand description
Common interface used by tracing to inspect a jig’s outcome without
knowing whether the value is a Request, Response, or Branch.